@@ -8,14 +8,15 @@
 
 #include <string>
 #include <vector>
+#include "core/exceptions/assert_not_null.hpp"
 #include "core/exceptions/OperationNotSupportedException.hpp"
 #include "core/attributes/Attribute.hpp"
-//#include "core/attributes/AttributeValueMap.hpp"
+//#include "core/stores/_impl/AttributeValueMap.hpp"
 #include "core/utils/CSVReader.hpp"
-#include "core/datastructures/objects/Object.hpp"
-#include "networks/_impl/Graph.hpp"
+#include "core/objects/Object.hpp"
+//#include "networks/_impl/Graph.hpp"
 #include "objects/Vertex.hpp"
-#include "objects/Edge.hpp"
+//#include "objects/Edge.hpp"
 #include "io/_impl/MultilayerMetadata.hpp"
 #include "io/_impl/MultilayerIOFileSection.hpp"
 
@@ -55,6 +56,15 @@ read_multilayer_data(
     char separator
 );
 
+template <typename ML>
+void
+read_actor_attributes(
+    ML* ml,
+    const MultilayerMetadata& meta,
+    const std::string& infile,
+    char separator
+);
+
 /**
  * Utility function to read ...
  * @param graph_type...
@@ -68,10 +78,12 @@ read_multilayer_type(
 );
 
 
+
 template <typename ML>
 const Vertex*
 read_actor(
-    ML* g,
+    ML* ml,
+    typename ML::layer_type* g,
     const std::vector<std::string>& fields,
     size_t from_idx,
     size_t line_number
@@ -83,11 +95,15 @@ read_actor(
 
     std::string actor_name = fields.at(from_idx);
 
-    auto actor = g->actors()->add(actor_name);
-
+    auto actor = ml->actors()->get(actor_name);
+    
     if (!actor)
     {
-        actor = g->actors()->get(actor_name);
+        actor = g->vertices()->add(actor_name);
+    }
+    else
+    {
+        g->vertices()->add(actor);
     }
 
     return actor;
@@ -151,8 +167,8 @@ read_multilayer_data(
         {
         case MultilayerIOFileSection::ACTORS:
         {
-
-            read_vertex(ml, fields, meta, csv.row_num());
+            // @todo no longer actors before layers
+            //read_vertex(ml, fields, meta, csv.row_num());
             break;
         }
 
@@ -203,6 +219,73 @@ read_multilayer_data(
 }
 
 
+template <typename ML>
+void
+read_actor_attributes(
+    ML* ml,
+    const MultilayerMetadata& meta,
+    const std::string& infile,
+    char separator
+)
+{
+
+    // PASS 3
+
+    core::CSVReader csv;
+    csv.trim_fields(true);
+    csv.set_field_separator(separator);
+    csv.set_comment("--");
+    csv.open(infile);
+
+    MultilayerIOFileSection section = MultilayerIOFileSection::EDGES;
+
+    while (csv.has_next())
+    {
+
+        std::vector<std::string> fields = csv.get_next();
+        std::string line = csv.get_current_raw_line();
+        // std::cout << line << std::endl;
+        // remove trailing spaces
+        line.erase(line.find_last_not_of(" \t")+1);
+        line.erase(0,line.find_first_not_of(" \t"));
+
+        if (line.size()==0)
+        {
+            continue;
+        }
+
+        // if new section starts here, set the current section and proceed
+        if (new_multilayer_section_start(line))
+        {
+            section = get_multilayer_section(line);
+            //fields = csv.get_next();
+            continue;
+        }
+
+        switch (section)
+        {
+        case MultilayerIOFileSection::ACTORS:
+        {
+            // @todo no longer actors before layers
+            read_vertex(ml, fields, meta, csv.row_num());
+            break;
+        }
+
+        case MultilayerIOFileSection::INTRALAYER_VERTICES:
+        case MultilayerIOFileSection::INTRALAYER_EDGES:
+        case MultilayerIOFileSection::INTERLAYER_EDGES:
+        case MultilayerIOFileSection::EDGES:
+            break;
+        
+
+        default:
+            break;
+        }
+    }
+
+}
+
+
 
 template <typename ML, typename G>
 G*
