@@ -7,20 +7,10 @@ Vertex::
 Vertex(
     const std::string& name
 ) :
-    NamedObject(name), key(name)
+    name(name)
 {
 }
 
-/*
-std::shared_ptr<const Vertex>
-Vertex::
-create(
-    const key_type& name
-)
-{
-    return std::make_shared<const Vertex>(name);
-}
-*/
 
 std::string
 Vertex::
@@ -30,6 +20,15 @@ to_string() const
 }
 
 
+Vertex::key_type
+Vertex::
+key(
+) const
+{
+    return name;
+}
+
+
 std::ostream&
 operator<<(std::ostream& os, const Vertex& v)
 {
@@ -37,5 +36,6 @@ operator<<(std::ostream& os, const Vertex& v)
     return os;
 }
 
+
 }
 }
